#!/bin/sh -efu

[ ! -e /etc/integrity/notify.conf ] || . /etc/integrity/notify.conf

LOGDIR="${LOGDIR:-/var/log/integrityd}"
LOGCONF="${LOGCONF:-/etc/integrity/log.conf}"
DESK_MESSAGE_FILE="${DESK_MESSAGE_FILE:-/etc/integrity/desktop_message}"
TTY_MESSAGE_FILE="${TTY_MESSAGE_FILE:-/etc/integrity/message}"
PATTERN="${PATTERN:-INTEGRITY_DATA}"
NOTIFY_ALSO="${NOTIFY_ALSO:-/etc/integrity/also}"
MIN_UID="${MIN_UID:-500}"

_start_time="$(echo | tai64n)"
_check_time=1

# Checks if the given timestamp isn't before the start time
# of the program. The actual comparison is made until the
# first positive result and then cached.
#
# args: tai64n-timestamp
# returns: 0 --- greater or equal to the start time, 1 --- before it.
check_timestamp()
{
    [ $_check_time -ne 0 ] || return 0

    local ts="$1"
    local _ts=

    case "${BASH_VERSION:-0.0}" in
        [012].*)
            _ts="$(echo -e -n "$ts\n$_start_time" | sort -r | head -1)"
            if [ "$_ts" != "$ts" ]; then
                return 1
            else
                _check_time=0
                return 0
            fi
            ;;
        *)
	    #shellcheck disable=SC3012
            if [ "$ts" '>' "$_start_time" -o "$ts" = "$_start_time" ]; then
                _check_time=0
                return 0
            else
                return 1
            fi
            ;;
    esac
}

# Compares the given UID with the MIN_UID configuration
# parameter.
#
# args: UID
# returns: 0 -- given UID >= MIN_UID, 1 -- otherwise.
check_uid() {
    [ "$1" -ge "$MIN_UID" ] || return 1
    return 0
}
